@@ -12,8 +12,6 @@ def Run(Parameters: dict, JavaJarsPath: str=None):
 	""" This function calls the cyclic IF segmentation pipeline using the given parameters.
 		Args:
 			:param Parameters: A dictionary containing all the parameters.
-			:param JavaXmx: .
-			:param JavaXms: .
 			:param JavaJarsPath: .
 	"""
 	
@@ -22,13 +20,15 @@ def Run(Parameters: dict, JavaJarsPath: str=None):
 			'SegmentNuclei_RoundToSegment',
 			'SegmentNuclei_Model', 'SegmentNuclei_BorderEffectSize', 'SegmentNuclei_BatchSize',
 			'SegmentNuclei_CheckOverlap', 'SegmentNuclei_SaveNuclei', 'SegmentNuclei_Threshold',
-			'SegmentCells_DilationteRatio',
+			'SegmentCells_DilationRatio',
 			'ExitAfterSegmentation', 'Background_Subtraction',
 			'FE_SaveImages', 'FE_BiasedFeaturesOnly', 'FE_DistanceFromBorder',
 			'Segmentation', 'Registration_And_Segmentation', 'FeaturesExtraction', 'QualityControl']
 	
 	for key in Parameters.keys():
 		if key not in Keys:
+			print("Unknown parameter: '" + key + "'", file=sys.stderr)
+			print(*Keys, sep='\n')
 			raise Exception("Unknown parameter: '" + key + "'")
 	
 	if JavaJarsPath is None:
@@ -43,8 +43,8 @@ def Run(Parameters: dict, JavaJarsPath: str=None):
 		else:
 			Java_Xms = Parameters['Java_Xms']
 	else:
-		Java_Xms = "4G"
-			
+		Java_Xms = "8G"
+	
 	if 'Java_Xmx' in Parameters and Parameters['Java_Xmx'] is not None:
 		if not isinstance(Parameters['Java_Xmx'], str):
 			raise Exception("Parameter 'Java_Xmx' must be a string, '"
@@ -52,7 +52,7 @@ def Run(Parameters: dict, JavaJarsPath: str=None):
 		else:
 			Java_Xmx = Parameters['Java_Xmx']
 	else:
-		Java_Xmx = "8G"
+		Java_Xmx = "12G"
 	
 	Java_Options = "-noverify -Xms" + Java_Xms + " -Xmx" + Java_Xmx
 	
@@ -61,18 +61,12 @@ def Run(Parameters: dict, JavaJarsPath: str=None):
 	java = open("cycIFAAP.java", "w")
 	
 	java.write('import softwares.ohsu.cyclicif.CyclicIF;\n')
-	java.write('import init.Initializer;\n\n')
-	if JavaJarsPath is not None:
-		java.write('import init.Native;;\n\n')
 	
 	java.write('public class cycIFAAP\n')
 	java.write('{\n\n')
 	
 	java.write('public static void main(String[] args) throws Exception\n')
 	java.write('\t{\n')
-	if JavaJarsPath is not None:
-		java.write('\tNative.LibPath = "' + JavaJarsPath + '" ;\n')
-	java.write('\tInitializer.Start() ;\n\n')
 	
 	if 'nbCPU' not in Parameters: raise Exception("'nbCPU' parameter missing.")
 	java.write('\tfinal int nbCPU = ' + str(Parameters['nbCPU']) + ' ;\n\n')
@@ -172,14 +166,14 @@ def Run(Parameters: dict, JavaJarsPath: str=None):
 		raise Exception("Wrong value for parameter 'SegmentNuclei_SaveNuclei', boolean (True/False) expected, '"
 						+ str(Parameters['SegmentNuclei_SaveNuclei']) + "' found.")
 	
-	if 'SegmentCells_DilationteRatio' not in Parameters or Parameters['SegmentCells_DilationteRatio'] is None:
-		java.write('\tcif.SegmentCells_DilationteRatio = 1.0 ;\n')
-	elif isinstance(Parameters['SegmentCells_DilationteRatio'], float) and \
-		0.0 < Parameters['SegmentCells_DilationteRatio']:
-		java.write('\tcif.SegmentCells_DilationteRatio = %f ;\n' % Parameters['SegmentCells_DilationteRatio'])
+	if 'SegmentCells_DilationRatio' not in Parameters or Parameters['SegmentCells_DilationRatio'] is None:
+		java.write('\tcif.SegmentCells_DilationRatio = 1.0 ;\n')
+	elif isinstance(Parameters['SegmentCells_DilationRatio'], float) and \
+		0.0 < Parameters['SegmentCells_DilationRatio']:
+		java.write('\tcif.SegmentCells_DilationRatio = %f ;\n' % Parameters['SegmentCells_DilationRatio'])
 	else:
-		raise Exception("Wrong value for parameter 'SegmentNuclei_CheckOverlap', positive float expected, '"
-						+ str(Parameters['SegmentNuclei_CheckOverlap']) + "' found.")
+		raise Exception("Wrong value for parameter 'SegmentCells_DilationRatio', positive float expected, '"
+						+ str(Parameters['SegmentCells_DilationRatio']) + "' found.")
 	
 	if 'Background_Subtraction' not in Parameters or Parameters['Background_Subtraction'] is None \
 		or Parameters['Background_Subtraction']:
